@@ -9,23 +9,28 @@ class PyTwoFaas():
     print self.cToken
 
   def sendAuth(self, clientId, factor, authType):
-    if authType == 'email':
+    if authType is not "email":
       payload = { 'userID' : clientId, 'compTK': self.cToken, 'userNum': factor }
     else:
       payload = { 'userID' : clientId, 'compTK': self.cToken, 'userEmail': factor }
     r = requests.post(self.url + "/init/" + authType, data=payload)
-    print(r.text)
+    return r.json()
 
   def sendAuthSMS(self, clientId, phoneNum):
-    sendAuth(self, clientId, phoneNum, "sms")
+    self.sendAuth(clientId, phoneNum, "sms")
 
-  def sendAuthCall(self, cliendId, phoneNum):
-    sendAuth(self, clientId, phoneNum, "call")
+  def sendAuthCall(self, clientId, phoneNum):
+    self.sendAuth(clientId, phoneNum, "call")
 
-  def sendAuthEmail(self, cliendId, email):
-    sendAuth(self, clientId, phoneNum, "email")
+  def sendAuthEmail(self, clientId, email):
+    self.sendAuth(clientId, phoneNum, "email")
 
   def sendUserInput(self, clientId, code):
     payload = {'userID' :clientId,'compTK':self.cToken,'twoAuth':code}
     r = requests.post(self.url + "/validate", data=payload)
-    print(r.text)
+    return r.json()
+
+  def isAuthenticatedUser(self, clientId):
+    payload = { 'userID': clientId, 'compTK':self.cToken}
+    r = requests.post(self.url + "/valid", data=payload)
+    return r.json()
\ No newline at end of file
